@@ -1039,6 +1039,7 @@ bye:
     }
 }
 
+#ifndef MINIMAL
 void domlsd(const char *base)
 {
     char           line[PATH_MAX + 1];
@@ -1050,8 +1051,8 @@ void domlsd(const char *base)
 
     if (*base != 0 && chdir(base) != 0) {
         if (*base++ == '-') {
-            while (!isspace((unsigned char) *base++));
-            while (isspace((unsigned char) *base++));
+            while (*base != 0 && !isspace((unsigned char) *base++));
+            while (*base != 0 && isspace((unsigned char) *base++));
             if (*base != 0 && chdir(base) != 0) {
                 addreply_noformat(550, MSG_STAT_FAILURE2);
                 return;
@@ -1103,3 +1104,4 @@ bye:
         die(421, LOG_ERR, "chdir: %s", strerror(errno));
     }
 }
+#endif
