@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Tempo expirado"
 #define MSG_CAPABILITIES "No foi possvel trocar capacidades"
 #define MSG_CLIENT_CLOSED_CNX "Cliente encerrou a conexo"
@@ -87,12 +88,12 @@
 #define MSG_ANON_CANT_DELETE "Usurios annimos no tm permisso para remover arquivos"
 #define MSG_ANON_CANT_OVERWRITE "Usurios annimos no tm permisso para sobrescrever arquivos existentes"
 #define MSG_DELE_FAILED "No foi possvel remover %s"
-#define MSG_DELE_SUCCESS "%s foi removido"
+#define MSG_DELE_SUCCESS "%s%s%s%s foi removido"
 #define MSG_DELE_TOTAL_FAILURE "Nenhum arquivo foi removido"
 #define MSG_LOAD_TOO_HIGH \
-	"A carga era %3.2f quando a conexo foi realizada. No  permitido recebimento\n" \
-	"de arquivos por usurios annimos quando a carga estiver to alta.\n" \
-	"Envio de arquivos  sempre permitido."
+    "A carga era %3.2f quando a conexo foi realizada. No  permitido recebimento\n" \
+    "de arquivos por usurios annimos quando a carga estiver to alta.\n" \
+    "Envio de arquivos  sempre permitido."
 #define MSG_OPEN_FAILURE "No foi possvel abrir %s"
 #define MSG_OPEN_FAILURE2 "No foi possvel abrir esse arquivo"
 #define MSG_STAT_FAILURE "No foi possvel determinar o tamanho do arquivo"
@@ -101,12 +102,12 @@
 #define MSG_REST_RESET "Restart offset reinicializado em 0"
 #define MSG_NOT_REGULAR_FILE "Somente arquivos comuns podem ser recebidos"
 #define MSG_NOT_MODERATED \
-	"Este arquivo foi enviado por um usurio annimo. Porm ainda no\n" \
-	"foi aprovado pelos administradores do site para poder ser recebido."
+    "Este arquivo foi enviado por um usurio annimo. Porm ainda no\n" \
+    "foi aprovado pelos administradores do site para poder ser recebido."
 #define MSG_RATIO_DENIAL \
-	"Desculpe, a proporo de envio/recebimento  %u:%u .\n" \
-	"At o momento voc enviou %llu Kb e recebeu %llu Kb.\n" \
-	"Por favor envie mais arquivos e tente fazer o recebimento posteriormente."
+    "Desculpe, a proporo de envio/recebimento  %u:%u .\n" \
+    "At o momento voc enviou %llu Kb e recebeu %llu Kb.\n" \
+    "Por favor envie mais arquivos e tente fazer o recebimento posteriormente."
 #define MSG_NO_MORE_TO_DOWNLOAD "No h mais nada para receber"
 #define MSG_WINNER "O computador  seu amigo. Confie nele"
 #define MSG_KBYTES_LEFT "%.1f kbytes para receber"
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nova conexo a partir de %s"
 #define MSG_WELCOME_TO "Bem-vindo a"
 #define MSG_MAX_USERS "%lu usurios (o mximo) j esto conectados, desculpe"
-#define MSG_NB_USERS "Voc  o usurio nmero %d de %d permitidos"
+#define MSG_NB_USERS "Voc  o usurio nmero %u de %u permitidos"
 #define MSG_WELCOME_TIME "Hora local agora  %02d:%02d. Porta do servidor: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Somente FTP annimo  permitido aqui"
 #define MSG_RATIOS_EVERYONE "PROPORES ESTO HABILITADAS PARA TODOS :"
@@ -205,7 +206,7 @@
 #define MSG_ILLEGAL_QUOTA "Cota invlida"
 #define MSG_QUOTA_FILES "%llu arquivos usados (%d%%) - autorizado: %llu arquivos"
 #define MSG_QUOTA_SIZE "%llu Kbytes usados (%d%%) - autorizado: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Cota excedida : %s no ser armazenado"
+#define MSG_QUOTA_EXCEEDED "Cota excedida : [%s] no ser armazenado"
 #define MSG_AUTH_UNKNOWN "Mtodo de autenticao desconhecido"
 #define MSG_PDB_BROKEN "No foi possvel ler o arquivo indexado do puredb (ou um formato antigo foi detectado) - Experimente pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s  um apelido para %s."
@@ -214,3 +215,20 @@
 #define MSG_ALIASES_LIST "Os seguintes apelidos esto disponveis :"
 #define MSG_PERUSER_MAX "No posso aceitar mais do que %lu conexes do mesmo usurio"
 #define MSG_IPV6_OK "Conexes IPv6 tambm so bem-vindas neste servidor"
+#define MSG_TLS_INFO "TLS: Habilitado %s com %s, criptografia de %d bits"
+#define MSG_TLS_WEAK "TLS: Criptografia muito fraca"
+#define MSG_TLS_NEEDED "Desculpe, sesses sem criptografia no so aceitas neste servidor.\n" \
+    "Por favor reconecte-se usando mecanismos de segurana TLS."
+#define MSG_ILLEGAL_CHARSET "Conjunto de caracteres ilegal"
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
+#define MSG_PROT_OK "Data protection level set to \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
+#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
+#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
+#define MSG_READY_TO_PROCEED "Ready to proceed"
+#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
+#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
+#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
