@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "O"
 #define MSG_CAPABILITIES "Lkʯ"
 #define MSG_CLIENT_CLOSED_CNX "Τsu"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "ΦWϥΪ̤Rɮ"
 #define MSG_ANON_CANT_OVERWRITE "ΦWϥΪ̤мg{sɮ"
 #define MSG_DELE_FAILED "LkR %s"
-#define MSG_DELE_SUCCESS "R %s"
+#define MSG_DELE_SUCCESS "R %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "SRɮ"
 #define MSG_LOAD_TOO_HIGH "zsuɭtO %3.2f CtpɡAڭ̤ΦWϥΪ̤UC\nWǫhOiH"
 
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION " %s ssu"
 #define MSG_WELCOME_TO "wӨ"
 #define MSG_MAX_USERS "%lu ϥΪ(̤j)wgnJAp"
-#define MSG_NB_USERS "zO %d ӨϥΪ̡A̦hiF %d ӳsu"
+#define MSG_NB_USERS "zO %u ӨϥΪ̡A̦hiF %u ӳsu"
 #define MSG_WELCOME_TIME "{baɶO %02d:%02d CAf: %uC"
 #define MSG_ANONYMOUS_FTP_ONLY "o̥uΰΦWFTP"
 #define MSG_RATIOS_EVERYONE "wEVERYONEҥΤv:"
@@ -205,7 +206,7 @@
 #define MSG_ILLEGAL_QUOTA "LĪB"
 #define MSG_QUOTA_FILES "%llu ɮ׼ƨϥ (%d%%) - vi: %llu ɮ"
 #define MSG_QUOTA_SIZE "%llu Kbytesϥ (%d%%) - vi: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "WLB: %s |Qxs"
+#define MSG_QUOTA_EXCEEDED "WLB: [%s] |Qxs"
 #define MSG_AUTH_UNKNOWN "Ҥk"
 #define MSG_PDB_BROKEN "LkŪindexed puredb(ΰ®榡) - ո pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s OOWA %s "
@@ -214,3 +215,20 @@
 #define MSG_ALIASES_LIST "HUOWiΡG"
 #define MSG_PERUSER_MAX "LkӦۦP@ϥΪ̶WL %lu su"
 #define MSG_IPV6_OK "oD]wIPv6su"
+#define MSG_TLS_INFO "TLS: ҥ %s with %s, %d 줸[K"
+#define MSG_TLS_WEAK "TLS: KX"
+#define MSG_TLS_NEEDED "pAA妡suC\n" \
+    "ШϥTLSwssuC"
+#define MSG_ILLEGAL_CHARSET "Illegal charset"
+#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
+#define MSG_PROT_OK "Data protection level set to \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
+#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
+#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
+#define MSG_READY_TO_PROCEED "Ready to proceed"
+#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
+#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
+#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
