@@ -7,20 +7,21 @@ int main(void)
 {
     puts("Please compile the server with --with-uploadscript\n"
          "to use this feature. Thank you.");
-    
+
     return 0;
 }
 #else
 
 # include "ftpd.h"
 # include "upload-pipe.h"
+# include "safe_rw.h"
 # include "pure-uploadscript_p.h"
 
 #ifdef WITH_DMALLOC
 # include <dmalloc.h>
 #endif
 
-static inline void setcloexec(const int fd)
+static void setcloexec(const int fd)
 {
     fcntl(fd, F_SETFD, FD_CLOEXEC);
 }
@@ -30,15 +31,15 @@ static int upload_pipe_ropen(void)
     struct stat st;
     int upload_pipe_fd;
     unsigned int tries = OPEN_TRIES;
-        
+
     again:
     if ((upload_pipe_fd =
          open(UPLOAD_PIPE_FILE, O_RDONLY | O_NOFOLLOW)) == -1) {
-	if (tries > 0) {
-	    tries--;
-	    (void) sleep(OPEN_DELAY);
-	    goto again;
-	}
+        if (tries > 0) {
+            tries--;
+            (void) sleep(OPEN_DELAY);
+            goto again;
+        }
         perror("Unable to open " UPLOAD_PIPE_FILE);
         return -1;
     }
@@ -52,6 +53,7 @@ static int upload_pipe_ropen(void)
 #endif
         ) {
         fprintf(stderr, "Insecure permissions on " UPLOAD_PIPE_FILE "\n");
+        (void) close(upload_pipe_fd);
         return -1;
     }
     return upload_pipe_fd;
@@ -61,12 +63,12 @@ static int readchar(const int upload_file_fd)
 {
     ssize_t ret;
     unsigned char c;
-    
+
     while ((ret = read(upload_file_fd, &c, (size_t) 1U)) < (ssize_t) 0 &&
            errno == EINTR);
     if (ret <= (ssize_t) 0) {
         return EOF;
-    } 
+    }
     return (int) c;
 }
 
@@ -74,13 +76,13 @@ static int readpipe(const int upload_file_fd,
                     char ** const r_who, char ** const r_file)
 {
     static char who[MAX_USER_LENGTH + 1U];
-    static char file[MAXPATHLEN + VHOST_PREFIX_MAX_LEN];
+    static char file[PATH_MAX + VHOST_PREFIX_MAX_LEN];
     const char * const whoend = &who[sizeof who];
     const char * const fileend = &file[sizeof file];
-    char *whopnt = who;    
+    char *whopnt = who;
     char *filepnt = file;
     int c;
-    
+
     *r_who = NULL;
     *r_file = NULL;
     do {
@@ -100,7 +102,7 @@ static int readpipe(const int upload_file_fd,
         }
         *whopnt = (char) c;
         whopnt++;
-    }    
+    }
     while (filepnt != fileend) {
         c = readchar(upload_file_fd);
         if (c == EOF || (c != 0 && ISCTRLCODE(c))) {
@@ -114,38 +116,38 @@ static int readpipe(const int upload_file_fd,
     }
     *r_who = who;
     *r_file = file;
-    
+
     return 0;
 }
 
-/* 
+/*
  * When we are using virtual hosts, the file looks like :
  * <ip address>:<path>
  */
 
 static char *checkvirtual(char *path)
 {
-    static char buf[MAXPATHLEN + 1];
+    static char buf[PATH_MAX + 1];
     char *path_pnt;
-    
+
     if (path == NULL || *path == '/' ||
         (path_pnt = strstr(path, ":/")) == NULL) {
         return path;
     }
     *path_pnt = 0;
-    if (SNCHECK(snprintf(buf, sizeof buf, VHOST_PATH "/%s%s", 
+    if (SNCHECK(snprintf(buf, sizeof buf, VHOST_PATH "/%s%s",
                          path, path_pnt + 1), sizeof buf)) {
         /* Better avoid processing than risking a security flaw */
         return NULL;
     }
-    
+
     return buf;
 }
 
 static int closedesc_all(const int closestdin)
 {
     int fodder;
-    
+
     if (closestdin != 0) {
         (void) close(0);
         if ((fodder = open("/dev/null", O_RDONLY)) == -1) {
@@ -164,14 +166,13 @@ static int closedesc_all(const int closestdin)
     if (fodder > 2) {
         (void) close(fodder);
     }
-    
     return 0;
 }
 
 static void dodaemonize(void)
 {
     pid_t child;
-    
+
     if (daemonize != 0) {
         if ((child = fork()) == (pid_t) -1) {
             perror("Daemonization failed - fork");
@@ -179,9 +180,12 @@ static void dodaemonize(void)
         } else if (child != (pid_t) 0) {
             _exit(EXIT_SUCCESS);
         } else if (setsid() == (pid_t) -1) {
-               perror("Daemonization failed : setsid");
+            perror("Daemonization failed : setsid");
         }
         (void) chdir("/");
+#ifdef HAVE_CLOSEFROM
+        (void) closefrom(3);
+#endif
         (void) closedesc_all(0);
     }
 }
@@ -191,19 +195,19 @@ static int init(void)
     (void) close(0);
 #ifndef NON_ROOT_FTP
     if (geteuid() != (uid_t) 0) {
-        fprintf(stderr, "Sorry, but you have to be r00t to run this program\n");
+        fprintf(stderr, "Sorry, but you have to be root to run this program\n");
         return -1;
     }
 #endif
-    
+
     return 0;
 }
 
 static void usage(void)
 {
-#ifndef NO_GETOPT_LONG    
+#ifndef NO_GETOPT_LONG
     const struct option *options = long_options;
-    
+
     do {
         printf("-%c\t--%s\t%s\n", options->val, options->name,
                options->has_arg ? "<opt>" : "");
@@ -232,17 +236,23 @@ static int parseoptions(int argc, char *argv[])
             daemonize = 1;
             break;
         }
+        case 'p': {
+            if ((uploadscript_pid_file = strdup(optarg)) == NULL) {
+                perror("Oh no ! More memory !");
+            }
+            break;
+        }
         case 'g': {
             const char *nptr;
             char *endptr;
-            
+
             nptr = optarg;
             endptr = NULL;
             gid = (gid_t) strtoul(nptr, &endptr, 10);
             if (!nptr || !*nptr || !endptr || *endptr) {
                 perror("Illegal GID - Must be a number\n");
             }
-            break;            
+            break;
         }
 #ifndef NO_GETOPT_LONG
         case 'h': {
@@ -250,24 +260,24 @@ static int parseoptions(int argc, char *argv[])
         }
 #endif
         case 'r': {
-            if ((script = strdup(optarg)) == NULL) {
+            if (script == NULL && (script = strdup(optarg)) == NULL) {
                 perror("Oh no ! More memory !");
             }
-            break;            
+            break;
         }
         case 'u': {
             const char *nptr;
             char *endptr;
-            
+
             nptr = optarg;
             endptr = NULL;
             uid = (uid_t) strtoul(nptr, &endptr, 10);
-            if (!nptr || !*nptr || !endptr || *endptr) {
+            if (!*nptr || !endptr || *endptr) {
                 perror("Illegal UID - Must be a number\n");
             }
             break;
         }
-        default: 
+        default:
             usage();
         }
     }
@@ -276,7 +286,7 @@ static int parseoptions(int argc, char *argv[])
 
 static int changeuidgid(void)
 {
-#ifndef NON_ROOT_FTP    
+#ifndef NON_ROOT_FTP
     if (
 #ifdef HAVE_SETGROUPS
         setgroups(1U, &gid) ||
@@ -294,7 +304,7 @@ static void newenv_ull(const char * const var, const unsigned long long val)
 {
     size_t s;
     char *v;
-    
+
     s = strlen(var) + (size_t) 42U;
     if ((v = malloc(s)) == NULL) {
         return;
@@ -310,7 +320,7 @@ static void newenv_uo(const char * const var, const unsigned int val)
 {
     size_t s;
     char *v;
-    
+
     s = strlen(var) + (size_t) 8U;
     if ((v = malloc(s)) == NULL) {
         return;
@@ -326,7 +336,7 @@ static void newenv_str(const char * const var, const char * const str)
 {
     size_t s;
     char *v;
-    
+
     if (str == NULL || *str == 0) {
         return;
     }
@@ -344,10 +354,10 @@ static void newenv_str(const char * const var, const char * const str)
 
 static void fillenv(const char * const who, const struct stat * const st)
 {
-#ifdef HAVE_PUTENV    
+#ifdef HAVE_PUTENV
     struct passwd *pwd;
     struct group *grp;
-    
+
     pwd = getpwuid(st->st_uid);
     grp = getgrgid(st->st_gid);
     newenv_ull("UPLOAD_SIZE", (unsigned long long) st->st_size);
@@ -368,12 +378,12 @@ static void fillenv(const char * const who, const struct stat * const st)
 #endif
 }
 
-static int run(const char * const who, const char * const file, 
+static int run(const char * const who, const char * const file,
                const int upload_pipe_fd)
 {
     struct stat st;
     pid_t pid;
-    
+
     if (script == NULL || *script == 0 ||
         file == NULL || *file == 0 ||
         lstat(file, &st) < 0 ||
@@ -394,60 +404,32 @@ static int run(const char * const who, const char * const file,
     } else if (pid != (pid_t) -1) {
 #ifdef HAVE_WAITPID
         (void) waitpid(pid, NULL, 0);
-#else
-        {
-            pid_t foundpid;
-            
-            while ((foundpid = wait3(NULL, 0, NULL)) != (pid_t) -1 &&
-                   foundpid != pid);
-        }
 #endif
     }
-    
-    return 0;
-}
 
-int safe_write(const int fd, const void *buf_, size_t count)
-{
-    register const char *buf = (const char *) buf_;
-    ssize_t written;
-        
-    while (count > (size_t) 0) {
-        for (;;) {
-            if ((written = write(fd, buf, count)) <= (ssize_t) 0) {
-                if (errno == EAGAIN) {
-                    sleep(1);
-                } else if (errno != EINTR) {
-                    return -1;
-                }
-                continue;
-            }
-            break;
-        }
-        buf += written;
-        count -= written;
-    }
     return 0;
 }
 
 static void updatepidfile(void)
 {
-    char buf[42];    
+    char buf[42];
+    size_t buf_len;
     int fd;
-    
-    if (SNCHECK(snprintf(buf, sizeof buf, "%lu\n", 
+
+    if (SNCHECK(snprintf(buf, sizeof buf, "%lu\n",
                          (unsigned long) getpid()), sizeof buf)) {
         return;
     }
-    if (unlink(UPLOADSCRIPT_PID_FILE) != 0 && errno != ENOENT) {
+    if (unlink(uploadscript_pid_file) != 0 && errno != ENOENT) {
         return;
     }
-    if ((fd = open(UPLOADSCRIPT_PID_FILE, O_CREAT | O_WRONLY | O_TRUNC |
+    if ((fd = open(uploadscript_pid_file, O_CREAT | O_WRONLY | O_TRUNC |
                    O_NOFOLLOW, (mode_t) 0644)) == -1) {
         return;
     }
-    if (safe_write(fd, buf, strlen(buf)) != 0) {
-        ftruncate(fd, (off_t) 0);
+    buf_len = strlen(buf);
+    if (safe_write(fd, buf, buf_len, -1) != (ssize_t) buf_len) {
+        (void) ftruncate(fd, (off_t) 0);
     }
     close(fd);
 }
@@ -457,7 +439,7 @@ int main(int argc, char *argv[])
     int upload_pipe_fd;
     char *who;
     char *file;
-    
+
 #ifdef HAVE_SETLOCALE
 # ifdef LC_MESSAGES
     (void) setlocale(LC_MESSAGES, "");
@@ -469,7 +451,7 @@ int main(int argc, char *argv[])
     (void) setlocale(LC_COLLATE, "");
 # endif
 #endif
-    
+
     if (init() < 0) {
         return -1;
     }
@@ -489,7 +471,7 @@ int main(int argc, char *argv[])
     updatepidfile();
     if (changeuidgid() < 0) {
         perror("Identity change");
-        (void) unlink(PID_FILE);
+        (void) unlink(uploadscript_pid_file);
         return -1;
     }
 #ifdef SIGPIPE
@@ -502,18 +484,18 @@ int main(int argc, char *argv[])
         if (readpipe(upload_pipe_fd, &who, &file) != 0) {
             (void) sleep(1);
             continue;
-        }        
+        }
         file = checkvirtual(file);
         if (file != NULL && who != NULL) {
             run(who, file, upload_pipe_fd);
         }
     }
-    /* Unreachable */
+    /* NOTREACHED */
 #if 0
     close(upload_pipe_fd);
-    (void) unlink(PID_FILE);
+    (void) unlink(uploadscript_pid_file);
 #endif
-    
+
     return 0;
 }
 
